[Spice-devel] [PATCH spice-gtk] Replace some missing "latency" terms

Frediano Ziglio fziglio at redhat.com
Tue Jun 18 08:15:50 UTC 2019


This follows up commit 887aedff41bdb89845e7cb349454a8dcbb515db4
"The video latency is in fact a margin".

Signed-off-by: Frediano Ziglio <fziglio at redhat.com>
---
 src/channel-display-priv.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/channel-display-priv.h b/src/channel-display-priv.h
index 495df7ac..16c12c6e 100644
--- a/src/channel-display-priv.h
+++ b/src/channel-display-priv.h
@@ -63,12 +63,12 @@ struct VideoDecoder {
      *
      * @decoder:   The video decoder.
      * @frame:     The compressed Spice frame.
      * @latency:   How long in milliseconds until the frame should be
      *             displayed. Negative values mean the frame is late.
      * @return:    False if the decoder can no longer decode frames,
      *             True otherwise.
      */
-    gboolean (*queue_frame)(VideoDecoder *video_decoder, SpiceFrame *frame, int latency);
+    gboolean (*queue_frame)(VideoDecoder *video_decoder, SpiceFrame *frame, int margin);
 
     /* The format of the encoded video. */
     int codec_type;
@@ -63,12 +63,12 @@ struct VideoDecoder {
      * @decoder:   The video decoder.
      * @frame:     The compressed Spice frame.
-     * @latency:   How long in milliseconds until the frame should be
+     * @margin:    How long in milliseconds until the frame should be
      *             displayed. Negative values mean the frame is late.
      * @return:    False if the decoder can no longer decode frames,
-- 
2.20.1



More information about the Spice-devel mailing list